# Django LDP resource

This module provides a list of resources, associated to circles. Each resource can be categorized in a different type and can be associated to keywords.

Previous version of this module is available in ETUC application : /applications/etuc/djangoldp-resources
